#!/usr/bin/env python3
import os
import re

def extract_docstring(file_path):
    try:
        with open(file_path, 'r', encoding='utf-8') as f:
            content = f.read()
            
        # Find the docstring
        docstring_match = re.search(r'"""(.*?)"""', content, re.DOTALL)
        if docstring_match:
            return '#!/usr/bin/env python3\n"""\n' + docstring_match.group(1).strip() + '\n"""'
    except Exception as e:
        print(f"Error processing {file_path}: {str(e)}")
    return None

def update_index_php():
    script_info = {}
    base_dir = os.path.dirname(os.path.abspath(__file__))
    
    # First collect all docstrings
    for filename in os.listdir(base_dir):
        if filename.endswith('.py') and filename != 'update_descriptions.py':
            file_path = os.path.join(base_dir, filename)
            docstring = extract_docstring(file_path)
            if docstring:
                script_info[filename] = docstring

    # Now read and update index.php
    index_path = os.path.join(base_dir, 'index.php')
    with open(index_path, 'r', encoding='utf-8') as f:
        content = f.read()

    # Find the $scriptInfo array
    script_info_match = re.search(r'\$scriptInfo\s*=\s*\[(.*?)\];', content, re.DOTALL)
    if not script_info_match:
        print("Could not find $scriptInfo array in index.php")
        return

    script_info_content = script_info_match.group(1)
    
    # Update each script's description
    for filename, docstring in script_info.items():
        # Find the current script entry
        script_entry_match = re.search(rf"'{filename}'\s*=>\s*\[(.*?)\]", script_info_content, re.DOTALL)
        if script_entry_match:
            entry_content = script_entry_match.group(1)
            
            # Find the description
            desc_match = re.search(r"'description'\s*=>\s*'(.*?<hr>.*?)'", entry_content, re.DOTALL)
            if desc_match:
                current_desc = desc_match.group(1)
                # Get the part after <hr>
                after_hr = re.search(r'<hr>(.*?)$', current_desc, re.DOTALL)
                if after_hr:
                    # Create new description with docstring
                    new_desc = f"{docstring}\n<hr>{after_hr.group(1).strip()}"
                    # Replace in content
                    new_entry = entry_content.replace(current_desc, new_desc)
                    script_info_content = script_info_content.replace(script_entry_match.group(0), 
                                                                    f"'{filename}' => [{new_entry}]")

    # Replace the entire $scriptInfo array
    new_content = content.replace(script_info_match.group(0), 
                                f"$scriptInfo = [{script_info_content}];")

    # Write back to file
    with open(index_path, 'w', encoding='utf-8') as f:
        f.write(new_content)

if __name__ == "__main__":
    update_index_php()
